﻿using System;
using System.Collections.Generic;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using Microsoft.QualityTools.Testing.Fakes;
using MyClient;
using VmManager;
using VmManager.Fakes;

namespace VmClientTests
{
    [TestClass]
    public class ClientTestsFakes
    {
        [TestInitialize]
        public void Setup()
        {

        }

        [TestMethod]
        public void TestGetVMNames()
        {
            using (ShimsContext.Create())
            {
                // Arrange
                var vm1 = new ShimVM
                {
                    GetName = () => "vm1"
                };
                var manager = new ShimManager
                {
                    GetVMs = () => new List<VM> { vm1 }
                };

                var client = new Client(manager);

                // Act
                List<String> names = client.GetVMNames();

                // Assert
                Assert.AreEqual(1, names.Count);
                Assert.AreEqual("vm1", names[0]);
            }
        }

        [TestMethod]
        public void TestVerifyManager()
        {
            // Arrange
          
            // Act
            var result = Client.VerifyManager();

            // Assert
            Assert.IsTrue(result);
        }

        [TestMethod]
        public void TestVerifyManagerTooOld()
        {
            using (ShimsContext.Create())
            {
                // Arrange
                ShimManager.GetVersion = () => 7;

                // Act
                var result = Client.VerifyManager();

                // Assert
                Assert.IsFalse(result);
            }
        }
    }
}
